summaryrefslogtreecommitdiff
path: root/test/functional/manufacturers_controller_test.rb
diff options
context:
space:
mode:
authorspag <spag@golwen.net>2012-12-31 08:50:27 +0100
committerspag <spag@golwen.net>2012-12-31 08:50:27 +0100
commitaed84444142604a62e37e57acfaaf957219e2c8d (patch)
treee00b1f5844590393171e0bc839ab516d39f5144d /test/functional/manufacturers_controller_test.rb
parentc24bd3a8212e85894b2f7c26e190fe5e89fbaaf2 (diff)
parent12c8f4c82770ded6ea6b519e4451ed6757419ddf (diff)
Merge branch 'develop' of github.com:amooma/GS5 into develop
Diffstat (limited to 'test/functional/manufacturers_controller_test.rb')
-rw-r--r--test/functional/manufacturers_controller_test.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/functional/manufacturers_controller_test.rb b/test/functional/manufacturers_controller_test.rb
index dad38e5..0b10f6d 100644
--- a/test/functional/manufacturers_controller_test.rb
+++ b/test/functional/manufacturers_controller_test.rb
@@ -2,14 +2,14 @@ require 'test_helper'
class ManufacturersControllerTest < ActionController::TestCase
setup do
- @tenant = Factory.create(:tenant)
- @user = Factory.create(:user)
+ @tenant = FactoryGirl.create(:tenant)
+ @user = FactoryGirl.create(:user)
@tenant.tenant_memberships.create(:user_id => @user.id)
@user.update_attributes!(:current_tenant_id => @tenant.id)
- @manufacturer = Factory.create(:manufacturer)
+ @manufacturer = FactoryGirl.create(:manufacturer)
@expected_status_if_not_authorized = :redirect
end
@@ -46,7 +46,7 @@ class ManufacturersControllerTest < ActionController::TestCase
#
# test "should create manufacturer" do
# assert_difference('Manufacturer.count') do
# post :create, manufacturer: Factory.build(:manufacturer).attributes
# end
#
# assert_redirected_to manufacturer_path(assigns(:manufacturer))
@@ -46,7 +46,7 @@ class ManufacturersControllerTest < ActionController::TestCase
# test "should create manufacturer" do
# assert_difference('Manufacturer.count') do
- # post :create, manufacturer: Factory.build(:manufacturer).attributes
+ # post :create, manufacturer: FactoryGirl.build(:manufacturer).attributes
# end
#